﻿using UnityEngine;
using System.Collections;

public class BossController : MonoBehaviour {

    public float moveSpeed = 600f;
    public float jumpForce = 10f;
    public bool onGround = true;
    public bool canWallJump = false;
    public bool alreadyJumped = false;
    public bool stickingToWall = false;
    public float timeForNextWallJump = 1f;
    public float timer;
    public bool goLeft, goRight, jump;
    public float aiTimer, loopTime, firstRun, secondRun, thirdRun;
    private Animator animator;
	
    void Start()
    {
        animator = GetComponent<Animator>();
    }

	void Update ()
    {

        aiTimer += Time.deltaTime;

        if (aiTimer > firstRun && aiTimer < secondRun)
        {
            goLeft = false;
            goRight = true;
        }
        else if (aiTimer > secondRun && aiTimer < thirdRun)
        {
            goRight = false;
            goLeft = true;
        }
        else if (aiTimer > thirdRun && aiTimer < loopTime)
        {
            goLeft = false;
            goRight = true;
        }
        else if (aiTimer > loopTime)
        {
            aiTimer = 0f;
            goRight = false;
            goLeft = true;
        }

        if (goRight)
        {
            GetComponent<Rigidbody2D>().AddRelativeForce(Vector2.right * moveSpeed * Time.deltaTime);

            transform.localScale = new Vector3(0.3f, 0.3f, 0.3f);

            animator.SetBool("IsMoving", true);

        }
        else if (goLeft)
        {
            GetComponent<Rigidbody2D>().AddRelativeForce(Vector2.left * moveSpeed * Time.deltaTime);

            transform.localScale = new Vector3(-0.3f, 0.3f, 0.3f);

            animator.SetBool("IsMoving", true);
        }
        else if (!goLeft && !goRight)
        {
            animator.SetBool("IsMoving", false);
        }

        if (jump)
        {
            if (onGround)
            {
                GetComponent<Rigidbody2D>().AddForce(Vector2.up * jumpForce);            
            }

            if (canWallJump && stickingToWall && !alreadyJumped)
            {
                GetComponent<Rigidbody2D>().AddForce(Vector2.up * 1 * jumpForce * 6);
                alreadyJumped = true;
            }
        }

        if (alreadyJumped)
        {
            timer += Time.deltaTime;
            canWallJump = false;
        }

        if (timer > timeForNextWallJump)
        {
            timer = 0f;
            alreadyJumped = false;
        }

        if (!onGround)
        {
            animator.SetBool("IsJumping", true);
        }
        else if (onGround)
        {
            animator.SetBool("IsJumping", false);
        }

    }

    void OnCollisionExit2D(Collision2D other)
    {
        if (other.gameObject.CompareTag("Floor"))
        {
            onGround = false;
        }
        else if (other.gameObject.CompareTag("Wall"))
        {
            canWallJump = false;
            stickingToWall = false;
        }

    }

    void OnCollisionStay2D(Collision2D other)
    {
        if (other.gameObject.CompareTag("Floor"))
        {
            onGround = true;
        }
        else if (other.gameObject.CompareTag("Wall") && !alreadyJumped)
        {
            canWallJump = true;
            stickingToWall = true;
        }
    }
}
