﻿using UnityEngine;
using System.Collections;

public class CharacterController : MonoBehaviour {

    public float moveSpeed = 600f;
    public float jumpForce = 10f;
    public bool onGround = true;
    public bool canWallJump = false;
    public bool alreadyJumped = false;
    public bool stickingToWall = false;
    public float timeForNextWallJump = 1f;
    public float timer;
    public Animator animator;

    void Start()
    {
        animator = GetComponent<Animator>();
    }
	
	void Update ()
    {
        float horizontal = Input.GetAxis("Horizontal");
        float jump = Input.GetAxis("Jump");

        if (horizontal > 0)
        {
            GetComponent<Rigidbody2D>().AddRelativeForce(Vector2.right * moveSpeed * horizontal * Time.deltaTime);

            transform.localScale = new Vector3(0.3f, 0.3f, 0.3f);

            animator.SetBool("IsMoving", true);

        }
        else if (horizontal < 0)
        {
            GetComponent<Rigidbody2D>().AddRelativeForce(Vector2.left * moveSpeed * horizontal * -1 * Time.deltaTime);

            transform.localScale = new Vector3(-0.3f, 0.3f, 0.3f);

            animator.SetBool("IsMoving", true);

        }
        else if (horizontal == 0)
        {
            animator.SetBool("IsMoving", false);
        }

        if (jump > 0)
        {            

            if (onGround)
            {
                GetComponent<Rigidbody2D>().AddForce(Vector2.up * jump * jumpForce);            
            }

            if (canWallJump && stickingToWall && !alreadyJumped)
            {
                GetComponent<Rigidbody2D>().AddForce(Vector2.up * 1 * jumpForce * 6);
                alreadyJumped = true;
            }
        }

        if (alreadyJumped)
        {
            timer += Time.deltaTime;
            canWallJump = false;
        }

        if (timer > timeForNextWallJump)
        {
            timer = 0f;
            alreadyJumped = false;
        }

        if (!onGround)
        {
            animator.SetBool("IsJumping", true);
        }
        else if (onGround)
        {
            animator.SetBool("IsJumping", false);
        }


    }

    void OnCollisionExit2D(Collision2D other)
    {
        if (other.gameObject.CompareTag("Floor"))
        {
            onGround = false;
        }
        else if (other.gameObject.CompareTag("Wall"))
        {
            canWallJump = false;
            stickingToWall = false;
        }

    }

    void OnCollisionStay2D(Collision2D other)
    {
        if (other.gameObject.CompareTag("Floor"))
        {
            onGround = true;
        }
        else if (other.gameObject.CompareTag("Wall") && !alreadyJumped)
        {
            canWallJump = true;
            stickingToWall = true;
        }
    }
}
